izug.basetheme
==============

This is theme for the websites of the canton of zug in switzerland.

It is not meant to be used outside of those websites and applications and will not be
useable on a bare plone installation.


Links
-----

- Main github project repository: https://github.com/4teamwork/izug.basetheme
- Issue tracker: https://github.com/4teamwork/izug.basetheme/issues
- Package on pypi: http://pypi.python.org/pypi/izug.basetheme


Copyright
---------

This package is copyright by `4teamwork <http://www.4teamwork.ch/>`_.

``izug.basetheme`` is licensed under GNU General Public License, version 2.
